@@ -12,11 +12,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import uuid
+import os
+
+from oslo_config import generator
 
 import keystone.conf
-from keystone import exception
-from keystone.server import wsgi
 from keystone.tests import unit
 
 
@@ -27,29 +27,19 @@ class ConfigTestCase(unit.TestCase):
 
     def config_files(self):
         config_files = super(ConfigTestCase, self).config_files()
-        # Insert the keystone sample as the first config file to be loaded
-        # since it is used in one of the code paths to determine the paste-ini
-        # location.
-        config_files.insert(0, unit.dirs.etc('keystone.conf.sample'))
-        return config_files
 
-    def test_paste_config(self):
-        self.assertEqual(unit.dirs.etc('keystone-paste.ini'),
-                         wsgi.find_paste_config())
-        self.config_fixture.config(group='paste_deploy',
-                                   config_file=uuid.uuid4().hex)
-        self.assertRaises(exception.ConfigFileNotFound,
-                          wsgi.find_paste_config)
-        self.config_fixture.config(group='paste_deploy', config_file='')
-        self.assertEqual(unit.dirs.etc('keystone.conf.sample'),
-                         wsgi.find_paste_config())
+        sample_file = 'keystone.conf.sample'
+        args = ['--namespace', 'keystone', '--output-file',
+                unit.dirs.etc(sample_file)]
+        generator.main(args=args)
+        config_files.insert(0, unit.dirs.etc(sample_file))
+        self.addCleanup(os.remove, unit.dirs.etc(sample_file))
+        return config_files
 
     def test_config_default(self):
         self.assertIsNone(CONF.auth.password)
         self.assertIsNone(CONF.auth.token)
-
-    def test_profiler_config_default(self):
-        """Check config.set_config_defaults() has set [profiler]enabled."""
+        # Check config.set_config_defaults() has set [profiler]enabled.
         self.assertEqual(False, CONF.profiler.enabled)
 
 
